@@ -18,7 +18,7 @@
 // |         Stephan Schmidt <schst@php-tools.net>                        |
 // +----------------------------------------------------------------------+
 //
-// $Id: Parser.php,v 1.21 2005/01/17 19:06:13 schst Exp $
+// $Id: Parser.php,v 1.25 2005/03/25 17:13:10 schst Exp $
 
 /**
  * XML Parser class.
@@ -356,6 +356,7 @@ class XML_Parser extends PEAR
         if ($this->isError( $result )) {
             return $result;
         }
+        return true;
     }
 
     // }}}
@@ -372,22 +373,16 @@ class XML_Parser extends PEAR
      */
     function setInputFile($file)
     {
-        $oldVal = false;
         /**
          * check, if file is a remote file
          */
         if (eregi('^(http|ftp)://', substr($file, 0, 10))) {
-            if (!ini_get('safe_mode')) {
-                $oldVal = ini_set('allow_url_fopen', 1);
-            } else {
-                return $this->raiseError('Remote files cannot be parsed, as safe mode is enabled.', XML_PARSER_ERROR_REMOTE);
+            if (!ini_get('allow_url_fopen')) {
+            	return $this->raiseError('Remote files cannot be parsed, as safe mode is enabled.', XML_PARSER_ERROR_REMOTE);
             }
         }
         
         $fp = @fopen($file, 'rb');
-        if ($oldVal !== false) {
-            ini_set('allow_url_fopen', $oldVal);
-        }
         if (is_resource($fp)) {
             $this->fp = $fp;
             return $fp;
@@ -579,6 +574,9 @@ class XML_Parser extends PEAR
     function funcStartHandler($xp, $elem, $attribs)
     {
         $func = 'xmltag_' . $elem;
+        if (strchr($func, '.')) {
+            $func = str_replace('.', '_', $func);
+        }
         if (method_exists($this->_handlerObj, $func)) {
             call_user_func(array(&$this->_handlerObj, $func), $xp, $elem, $attribs);
         } elseif (method_exists($this->_handlerObj, 'xmltag')) {
@@ -592,10 +590,13 @@ class XML_Parser extends PEAR
     function funcEndHandler($xp, $elem)
     {
         $func = 'xmltag_' . $elem . '_';
+        if (strchr($func, '.')) {
+            $func = str_replace('.', '_', $func);
+        }
         if (method_exists($this->_handlerObj, $func)) {
             call_user_func(array(&$this->_handlerObj, $func), $xp, $elem);
         } elseif (method_exists($this->_handlerObj, 'xmltag_')) {
-            call_user_func(array(&$this->_handlerObj, 'xmltag_'), $xp, $elem, $attribs);
+            call_user_func(array(&$this->_handlerObj, 'xmltag_'), $xp, $elem);
         }
     }
 
